@@ -322,6 +322,19 @@ class nid_read():
         frames = np.array(param['Frame'])[idx]
         channel = np.array(param['Dim2Name'])[idx]
 
+        frame_chan = [i + ';' + j for i,j in zip(frames,channel)]
+        
+        seen = set()
+        new_channel = []
+        for x in frame_chan:
+            if x not in seen:
+                new_channel.append(x)
+                seen.add(x)
+            else:
+                new_channel.append(x + '2')
+        channel = [x.split(';')[1] for x in new_channel]
+        
+
         out = {}
         for frame, chan, dat in zip(frames, channel, data):
             if frame not in out:
@@ -464,6 +477,7 @@ class nhf_read():
         
         self.data = toPandaDF(_data_out).unstack(level=0)
         self.param = pd.Series(prop_s)
+        fopen.close()
         
 
 def toPandaDF(user_dict):
@@ -495,11 +509,7 @@ def checkFileType(filename, cla):
         exit()
     
 
-if __name__=="__main__":
-    filename='..//example//Plotting_Data//MoS2.nid'
-    afm=read(filename,verbose=True)
-    print(afm.param)
-    
-    filename='..//example//2D_Plane_Removal//circles.nid'
+if __name__=="__main__":   
+    filename='..//example//Plane_Removal//circles.nid'
     afm=read(filename,verbose=True)
     print(afm.param)
